@@ -6,28 +6,15 @@ library(roxygen2)
 ## ----census, echo = T, eval = T, message = F----------------------------------
 library(RCzechia)
 library(ggplot2)
-library(readxl)
 library(dplyr)
-library(httr)
-library(sf)
+library(czso)
 
-tf <- tempfile(fileext = ".xls") # a temporary xls file
+src <- czso::czso_get_table("SLDB-VYBER") %>% 
+   select(uzkod, obyvatel = vse1111) %>% 
+   mutate(obyvatel = as.numeric(obyvatel)) 
 
-GET("https://raw.githubusercontent.com/jlacko/RCzechia/master/data-raw/zvcr034.xls", 
-    write_disk(tf))
-
-src <- read_excel(tf, range = "Data!B5:C97") # read in with original column names
-
-colnames(src) <- c("NAZ_LAU1", "obyvatel") # meaningful names instead of the original ones
-
-src <- src %>%
-  mutate(obyvatel = as.double(obyvatel)) %>% 
-    # convert from text to number
-  mutate(NAZ_LAU1 = ifelse(NAZ_LAU1 == "Hlavní město Praha", "Praha", NAZ_LAU1)) 
-    # rename Prague (from The Capital to a regular city)
-  
 okresni_data <- RCzechia::okresy("low") %>% # data shapefile
-  inner_join(src, by = "NAZ_LAU1") 
+  inner_join(src, by = c("KOD_OKRES" = "uzkod")) 
     # key for data connection - note the use of inner (i.e. filtering) join
 
 # report results
@@ -41,10 +28,6 @@ ggplot(data = okresni_data) +
   theme(legend.text.align = 1,
         legend.title.align = 0.5)
 
-
-
-
-
 ## ----geocode, echo = T, eval = T, message = F, warning = F,fig.width = 8, fig.height = 5----
 library(RCzechia)
 library(ggplot2)
@@ -131,18 +114,14 @@ ggplot() +
 #  library(dplyr)
 #  library(RCzechia)
 #  library(leaflet)
-#  library(sf)
+#  library(czso)
 #  
-#  src <- read.csv(url("https://raw.githubusercontent.com/jlacko/RCzechia/master/data-raw/unempl.csv"), stringsAsFactors = F)
-#  # open data on unemployment from Czech Statistical Office - https://www.czso.cz/csu/czso/otevrena_data
-#  # lightly edited for size (rows filtered)
-#  
-#  
-#  src <- src %>%
-#    mutate(KOD_OBEC = as.character(uzemi_kod))  # keys in RCzechia are of type character
+#  # metrika pro mapování - uchazeči za říjen
+#  metrika <- czso::czso_get_table("250169r20") %>%
+#     filter(obdobi == "20201031" & vuk == "NEZ0004")
 #  
 #  podklad <- RCzechia::obce_polygony() %>% # obce_polygony = municipalities in RCzechia package
-#    inner_join(src, by = "KOD_OBEC") %>% # linking by key
+#    inner_join(metrika, by = c("KOD_OBEC" = "uzemi_kod")) %>% # linking by key
 #    filter(KOD_CZNUTS3 == "CZ071") # Olomoucký kraj
 #  
 #  pal <- colorNumeric(palette = "viridis",  domain = podklad$hodnota)
@@ -188,7 +167,7 @@ ggplot() +
   geom_sf(data = KFME_grid(), size = .33, # all KFME grid cells, thin
           color = "gray80", fill = NA) + # in gray and without fill
   geom_sf(data = place,  color = "red", pch = 4) +  # X marks the spot!
-  ggtitle(paste("Location", obec, "in grid cell number", ctverec_id)) +
+  labs(title = paste("Location", obec, "in grid cell number", ctverec_id)) +
   theme_bw()
 
 
@@ -214,3 +193,32 @@ ggplot() +
   theme(axis.title = element_blank())
 
 
+## ----senat, echo = T, eval = T, message = F, warning = F----------------------
+
+library(RCzechia)
+library(ggplot2)
+library(dplyr)
+library(rvest)
+
+# official result of elections from Czech Statistical Office
+vysledky <- "https://www.volby.cz/pls/senat/se1111?xjazyk=CZ&xdatum=20201002&xv=7&xt=2" %>% 
+  xml2::read_html() %>%  # because rvest::html is deprecated
+  html_nodes(xpath = "//*[@id=\"se1111_t1\"]") %>%  # get the table by its xpath
+  html_table(fill = T) %>% 
+  .[[1]] %>% 
+  dplyr::select(OBVOD = Obvod, strana = `Volebnístrana`) %>% 
+  # pad OBVOD with zero to 2 places to align to RCzechia data format
+  mutate(OBVOD = stringr::str_pad(OBVOD, 2, side = "left", pad = "0"))
+
+podklad <- RCzechia::senat_obvody("low") %>% 
+  # match by key; left to preserve geometry of off cycle districts (NAs)
+  left_join(vysledky, by = "OBVOD") 
+
+ggplot() +
+  geom_sf(data = RCzechia::republika(), size = .85) + # Czech borders
+  geom_sf(data = podklad, aes(fill = strana)) +
+  labs(title = "Senate elections 2020") +
+  theme_bw()
+
+
+
